@@ -52,8 +52,10 @@ DetailedInfoDlg::DetailedInfoDlg( int el , QWidget *parent )
 	setFaceType( List );
 	setButtons( Help | User1 | User2 | Close );
 	setDefaultButton( Close );
-	setButtonGuiItem( User1, KGuiItem( i18nc( "Next element", "Next" ), "arrow-right", i18n( "Goes to the next element" ) ) );
-	setButtonGuiItem( User2, KGuiItem( i18nc( "Previous element", "Previous" ), "arrow-left", i18n( "Goes to the previous element" ) ) );
+	setButtonGuiItem( User1, KGuiItem( i18nc( "Next element", "Next" ),
+		    ( layoutDirection() == Qt::LeftToRight ) ? "arrow-right" : "arrow-left", i18n( "Goes to the next element" ) ) );
+	setButtonGuiItem( User2, KGuiItem( i18nc( "Previous element", "Previous" ),
+		    ( layoutDirection() == Qt::LeftToRight ) ? "arrow-left" : "arrow-right", i18n( "Goes to the previous element" ) ) );
 
 	m_baseHtml = KGlobal::dirs()->findResourceDir( "appdata", "data/" ) + "data/htmlview/";
 	m_baseHtml2 = KGlobal::dirs()->findResourceDir( "appdata", "data/" ) + "data/hazardsymbols/";
@@ -84,6 +86,8 @@ void DetailedInfoDlg::setElement( int el )
 
 	m_element = element;
 	m_elementNumber = el;
+
+        emit elementChanged( m_elementNumber );
 	
 	reloadContent();
 
