@@ -42,9 +42,11 @@
 #include "kstars.h"
 #include "kstarsdata.h"
 #include "skyobject.h"
+#include "starobject.h"
 #include "skymap.h"
 #include "detaildialog.h"
 #include "tools/altvstime.h"
+#include "Options.h"
 
 #include "indimenu.h"
 #include "indielement.h"
@@ -570,7 +572,24 @@ void ObservingList::slotOpenList() {
 
         while ( ! istream.atEnd() ) {
             line = istream.readLine();
-            SkyObject *o = ks->data()->objectNamed( line );
+
+            //If the object is named "star", add it by coordinates
+            SkyObject *o;
+            if ( line.startsWith( "star" ) ) {
+                QStringList fields = line.split( " ", QString::SkipEmptyParts );
+                dms ra = dms::fromString( fields[1], false ); //false = hours
+                dms dc = dms::fromString( fields[2], true );  //true  = degrees
+                SkyPoint p( ra, dc );
+                double maxrad = 1000.0/Options::zoomFactor();
+                o = ks->data()->skyComposite()->starNearest( &p, maxrad );
+            } else {
+                o = ks->data()->objectNamed( line );
+            }
+
+            //If we haven't identified the object, try interpreting the 
+            //name as a star's genetive name (with ascii letters)
+            if ( !o ) o = ks->data()->skyComposite()->findStarByGenetiveName( line );
+
             if ( o ) slotAddObject( o );
         }
 
@@ -642,7 +661,19 @@ void ObservingList::slotSaveList() {
     QTextStream ostream(&f);
     ostream << ListName << endl;
     foreach ( SkyObject* o, obsList() ) {
-        ostream << o->name() << endl;
+        if ( o->name() == "star" ) {
+            ostream << o->name() << "  " << o->ra()->Hours() << "  " << o->dec()->Degrees() << endl;
+        } else if ( o->type() == SkyObject::STAR ) {
+            StarObject *s = (StarObject*)o;
+
+            if ( s->name() == s->gname() ) {
+                ostream << s->name2() << endl;
+            } else { 
+                ostream << s->name() << endl;
+            }
+        } else {
+            ostream << o->name() << endl;
+        }
     }
 
     f.close();
